<?php
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: GET");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

include_once '../../config/database.php';

$database = new Database();
$db = $database->getConnection();

// Handle GET request
if ($_SERVER["REQUEST_METHOD"] == "GET") {
    // Get the promotion ID from the query string
    $promotion_id = isset($_GET["promotion_id"]) ? intval($_GET["promotion_id"]) : 0;

    // Prepare the SQL statement
    $sql = "SELECT p.name AS promotion_name, p.is_published, p.start_date, p.end_date, i.description, i.promoted_price, i.promotionQuantity
            FROM promotions p
            JOIN item i ON p.id = i.promotion_id
            WHERE p.id = :promotion_id";

    // Execute the statement
    $stmt = $db->prepare($sql);
    $stmt->bindParam(':promotion_id', $promotion_id);
    $stmt->execute();

    // Check if any rows were returned
    if ($stmt->rowCount() > 0) {
        // Fetch the rows and build an array of items
        $items = array();
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $item = array(
                "description" => $row["description"],
                "promoted_price" => $row["promoted_price"],
                "promoted_quantity" => $row["promotionQuantity"]
            );
            array_push($items, $item);

            // Store the promotion information from the first row
            $promotion_name = $row["promotion_name"];
            $is_published = $row["is_published"];
            $start_date = $row["start_date"];
            $end_date = $row["end_date"];
        }

        // Build the response object
        $response = array(
            "promotion_name" => $promotion_name,
            "is_published" => $is_published,
            "start_date" => $start_date,
            "end_date" => $end_date,
            "items" => $items
        );

        // Return the response object as JSON
        http_response_code(200);
        echo json_encode($response);
    } else {
        // No rows were returned
        http_response_code(404);
        echo json_encode(array("message" => "No items found for the given promotion ID."));
    }
}
?>
